@@ -1,4 +1,4 @@
-design.strip<-function (trt1, trt2,r, serie = 2, seed = 0, kinds = "Super-Duper")
+design.strip<-function (trt1, trt2,r, serie = 2, seed = 0, kinds = "Super-Duper",randomization=TRUE)
 {
 number<-10
 if(serie>0) number<-10^serie
@@ -9,15 +9,23 @@ if(serie>0) number<-10^serie
     seed <-.Random.seed[3]
     }
         set.seed(seed, kinds)
+a<-trt1[1:n1]
+b<-trt2[1:n2]
+if(randomization){
         a<-sample(trt1,n1)
         b<-sample(trt2,n2)
+}
         fila<-rep(b,n1)
         columna <- a[gl(n1,n2)]
         block <- rep(1,n1*n2)
     if (r > 1) {
     for (i in 2:r) {
+a<-trt1[1:n1]
+b<-trt2[1:n2]
+if(randomization){
         a<-sample(trt1,n1)
         b<-sample(trt2,n2)
+}
         fila<-c(fila,rep(b,n1))
         columna <- c(columna,a[gl(n1,n2)])
         block <- c(block,rep(i,n1*n2))
