@@ -1,4 +1,4 @@
-"kurtosis" <-
+`kurtosis` <-
 function(x) {
 x<-na.omit(x)
 n<-length(x)
