@@ -31,6 +31,7 @@ arrows(xmed,ymed,env[,first],0.9*env[,second],angle=angle,lwd=lwd,length=length)
 abline(v=xmed,h=ymed)
 }
 if(type==2){
+if (requireNamespace("klaR", quietly = TRUE)) {
 lugar <- env[,c(first,second,third)]
 clones <- gen[,c(first,second,third)]
 maxcp <- max(A[, c(first,second,third)])
@@ -43,31 +44,39 @@ nlugar <- nrow(lugar)
 point1 <- cbind(clones[, 1], clones[, 2], clones[, 3])
 point2 <- cbind(lugar[, 1], lugar[, 2], lugar[, 3])
 point3 <- cbind(c(0.6, 0.6, 0), c(0, 0.8, 0.8), c(0.6, 0, 0.6))
-suppressWarnings(warning(triplot(point1, cex = 0, grid = TRUE,
+suppressWarnings(warning(klaR::triplot(point1, cex = 0, grid = TRUE,
 label = "", center=TRUE,frame=TRUE)))
 if (number == TRUE)
-suppressWarnings(warning(text(tritrafo(point1), as.character(1:nclon),
+suppressWarnings(warning(text(klaR::tritrafo(point1), as.character(1:nclon),
 adj = c(0.5, 0), col = "blue", cex = 0.8)))
 if (number == FALSE)
-suppressWarnings(warning(text(tritrafo(point1), rownames(clones),
+suppressWarnings(warning(text(klaR::tritrafo(point1), rownames(clones),
 adj = c(0.5, 0), col = "blue", cex = 0.8)))
-suppressWarnings(warning(text(tritrafo(point2), rownames(lugar),
+suppressWarnings(warning(text(klaR::tritrafo(point2), rownames(lugar),
 adj = c(0.5, 0), col = "red", cex = 0.8)))
-suppressWarnings(warning(text(tritrafo(point3), xylabel[c(first,second,third)],
+suppressWarnings(warning(text(klaR::tritrafo(point3), xylabel[c(first,second,third)],
 adj = c(0.5, 0), cex = 1)))
-trilines(centerlines(3), lty = 2.5, col = "green", lwd = 2)
+klaR::trilines(klaR::centerlines(3), lty = 2.5, col = "green", lwd = 2)
 for (i in 1:nlugar) {
-suppressWarnings(warning(trilines(c(point2[i, 1], 1/3), c(point2[i, 2],
+suppressWarnings(warning(klaR::trilines(c(point2[i, 1], 1/3), c(point2[i, 2],
  1/3), c(point2[i, 3], 1/3),col = "red", lty = 1)))
 }
+} else {
+return("Please install the package klaR to plot triplot")
+}
 }
 if(type==3){
+if (requireNamespace("spdep", quietly = TRUE)) {
 plot(A[,first],A[,second],type="p",cex=0,xlab=xlab,ylab=ylab,xlim=xlim,ylim=ylim,...)
 text(env[,first],env[,second],rownames(env),col=ecol)
 text(gen[,first],gen[,second],ngen,col=gcol)
 coords<-as.matrix(gen[,c(first,second)])
-tri<-tri2nb(coords)
-relative <- graph2nb(soi.graph(tri,coords))
+tri<-spdep::tri2nb(coords)
+relative <- spdep::graph2nb(spdep::soi.graph(tri,coords))
 plot(relative,coords,add=TRUE,col=icol,cex=0.1)
 }
+else {
+return("Please install the package spdep to plot the spatial relationship")
+}
+}
 }
\ No newline at end of file
