@@ -1,5 +1,5 @@
 `resampling.model` <-
-function(model,data,k) {
+function(model,data,k,console=FALSE) {
 modelo<-model
 parte<-strsplit(model,"~")[[1]]
 model<-as.formula(model)
@@ -28,6 +28,7 @@ if(f[j] >= fc[j])cuenta[j]<-cuenta[j]+1
 for( j in 1:gk){
 xx[j,6]<-cuenta[j]/k
 }
+if(console){
 cat("\nResampling of the experiments\n")
 cat(rep("-",14),"\n")
 cat("Proposed model:",modelo,"\n")
@@ -38,6 +39,8 @@ cat("Samples:",k,"\n\n")
 xx<-as.matrix(xx)
 print(xx,na.print="")
 cat("---\n\n")
-return(list(solution=xx,acum=cuenta,samples=k))
+}
+out<-list(model=resample, solution=xx,acum=cuenta,samples=k)
+invisible(out)
 }
 
