@@ -121,7 +121,7 @@ print(summary(h5),row.names=FALSE)
 
 
 ###################################################
-### code chunk number 16: tutorial.Rnw:240-246
+### code chunk number 16: tutorial.Rnw:242-248
 ###################################################
 str(design.crd)
 trt <- c("A", "B", "C")
@@ -132,7 +132,7 @@ head(book1)
 
 
 ###################################################
-### code chunk number 17: tutorial.Rnw:253-262
+### code chunk number 17: tutorial.Rnw:255-264
 ###################################################
 str(design.rcbd)
 
@@ -146,7 +146,7 @@ print(matrix(book2[,1],byrow = TRUE, ncol = 5))
 
 
 ###################################################
-### code chunk number 18: tutorial.Rnw:266-270
+### code chunk number 18: tutorial.Rnw:268-272
 ###################################################
 str(design.lsd)
 trt <- c("A", "B", "C", "D")
@@ -155,14 +155,14 @@ print(outdesign$sketch)
 
 
 ###################################################
-### code chunk number 19: tutorial.Rnw:273-275
+### code chunk number 19: tutorial.Rnw:275-277
 ###################################################
 book <- zigzag(outdesign)
 print(matrix(book[,1],byrow = TRUE, ncol = 4))
 
 
 ###################################################
-### code chunk number 20: tutorial.Rnw:280-285
+### code chunk number 20: tutorial.Rnw:282-287
 ###################################################
 str(design.graeco)
 trt1 <- c("A", "B", "C", "D")
@@ -172,14 +172,14 @@ print(outdesign$sketch)
 
 
 ###################################################
-### code chunk number 21: tutorial.Rnw:288-290
+### code chunk number 21: tutorial.Rnw:290-292
 ###################################################
 book <- zigzag(outdesign)
 print(matrix(book[,1],byrow = TRUE, ncol = 4))
 
 
 ###################################################
-### code chunk number 22: tutorial.Rnw:295-303
+### code chunk number 22: tutorial.Rnw:297-305
 ###################################################
 str(design.youden)
 varieties<-c("perricholi","yungay","maria bonita","tomasa")
@@ -192,14 +192,14 @@ print(matrix(as.numeric(book[,1]),byrow = TRUE, ncol = r))
 
 
 ###################################################
-### code chunk number 23: tutorial.Rnw:306-308
+### code chunk number 23: tutorial.Rnw:308-310
 ###################################################
 book <- zigzag(outdesign)
 print(matrix(as.numeric(book[,1]),byrow = TRUE, ncol = r))
 
 
 ###################################################
-### code chunk number 24: tutorial.Rnw:314-321
+### code chunk number 24: tutorial.Rnw:316-323
 ###################################################
 str(design.bib)
 trt <- c("A", "B", "C", "D", "E" )
@@ -211,20 +211,20 @@ outdesign$parameters
 
 
 ###################################################
-### code chunk number 25: tutorial.Rnw:324-325
+### code chunk number 25: tutorial.Rnw:326-327
 ###################################################
 outdesign$sketch
 
 
 ###################################################
-### code chunk number 26: tutorial.Rnw:330-332
+### code chunk number 26: tutorial.Rnw:332-334
 ###################################################
 book <- zigzag(outdesign)
 matrix(book[,1],byrow = TRUE, ncol = 4)
 
 
 ###################################################
-### code chunk number 27: tutorial.Rnw:339-345
+### code chunk number 27: tutorial.Rnw:341-347
 ###################################################
 str(design.cyclic)
 trt <- c("A", "B", "C", "D", "E", "F" )
@@ -235,7 +235,7 @@ outdesign$sketch[[2]]
 
 
 ###################################################
-### code chunk number 28: tutorial.Rnw:350-354
+### code chunk number 28: tutorial.Rnw:352-356
 ###################################################
 book <- zigzag(outdesign)
 array(book$plots,c(3,6,2))->X
@@ -244,13 +244,13 @@ t(X[,,2])
 
 
 ###################################################
-### code chunk number 29: tutorial.Rnw:359-360
+### code chunk number 29: tutorial.Rnw:361-362
 ###################################################
 str(design.lattice)
 
 
 ###################################################
-### code chunk number 30: tutorial.Rnw:364-371
+### code chunk number 30: tutorial.Rnw:366-373
 ###################################################
 trt<-letters[1:9]
 outdesign <-design.lattice(trt, r = 3, serie = 2, seed = 33, 
@@ -262,7 +262,7 @@ head(book7)
 
 
 ###################################################
-### code chunk number 31: tutorial.Rnw:374-379
+### code chunk number 31: tutorial.Rnw:376-381
 ###################################################
 book <- zigzag(outdesign)
 array(book$plots,c(3,3,3)) -> X
@@ -272,7 +272,7 @@ t(X[,,3])
 
 
 ###################################################
-### code chunk number 32: tutorial.Rnw:384-394
+### code chunk number 32: tutorial.Rnw:386-396
 ###################################################
 str(design.alpha)
 trt <- letters[1:15]
@@ -287,7 +287,7 @@ t(A[,,2])
 
 
 ###################################################
-### code chunk number 33: tutorial.Rnw:397-401
+### code chunk number 33: tutorial.Rnw:399-403
 ###################################################
 book <- zigzag(outdesign)
 A<-array(book[,1], c(3,5,2))
@@ -296,7 +296,7 @@ t(A[,,2])
 
 
 ###################################################
-### code chunk number 34: tutorial.Rnw:407-416
+### code chunk number 34: tutorial.Rnw:409-418
 ###################################################
 str(design.dau)
 rm(list=ls())
@@ -310,7 +310,7 @@ detach(book9)
 
 
 ###################################################
-### code chunk number 35: tutorial.Rnw:419-424
+### code chunk number 35: tutorial.Rnw:421-426
 ###################################################
 book <- zigzag(outdesign)
 attach(book)
@@ -320,13 +320,13 @@ head(book)
 
 
 ###################################################
-### code chunk number 36: tutorial.Rnw:430-431
+### code chunk number 36: tutorial.Rnw:432-433
 ###################################################
 str(design.split)
 
 
 ###################################################
-### code chunk number 37: tutorial.Rnw:435-444
+### code chunk number 37: tutorial.Rnw:437-446
 ###################################################
 trt1<-c("A","B","C","D")
 trt2<-c("a","b","c")
@@ -340,32 +340,32 @@ q <- c(q,paste(book10$trt2[3*(i-1)+1],book10$trt2[3*(i-1)+2], book10$trt2[3*(i-1
 
 
 ###################################################
-### code chunk number 38: tutorial.Rnw:447-448
+### code chunk number 38: tutorial.Rnw:449-450
 ###################################################
 print(t(matrix(p,c(4,3))))
 
 
 ###################################################
-### code chunk number 39: tutorial.Rnw:451-452
+### code chunk number 39: tutorial.Rnw:453-454
 ###################################################
 print(t(matrix(q,c(4,3))))
 
 
 ###################################################
-### code chunk number 40: tutorial.Rnw:455-457
+### code chunk number 40: tutorial.Rnw:457-459
 ###################################################
 book <- zigzag(outdesign)
 head(book,5)
 
 
 ###################################################
-### code chunk number 41: tutorial.Rnw:461-462
+### code chunk number 41: tutorial.Rnw:463-464
 ###################################################
 str(design.strip)
 
 
 ###################################################
-### code chunk number 42: tutorial.Rnw:465-477
+### code chunk number 42: tutorial.Rnw:467-479
 ###################################################
 trt1<-c("A","B","C","D")
 trt2<-c("a","b","c")
@@ -382,7 +382,7 @@ print(B3)
 
 
 ###################################################
-### code chunk number 43: tutorial.Rnw:480-486
+### code chunk number 43: tutorial.Rnw:482-488
 ###################################################
 book <- zigzag(outdesign)
 head(book)
@@ -393,19 +393,19 @@ t(X[,,3])
 
 
 ###################################################
-### code chunk number 44: tutorial.Rnw:490-491
+### code chunk number 44: tutorial.Rnw:492-493
 ###################################################
 str(design.ab)
 
 
 ###################################################
-### code chunk number 45: tutorial.Rnw:494-495
+### code chunk number 45: tutorial.Rnw:496-497
 ###################################################
 trt <- c (4,2,3) # three factors with  4,2 and 3 levels.
 
 
 ###################################################
-### code chunk number 46: tutorial.Rnw:499-503
+### code chunk number 46: tutorial.Rnw:501-505
 ###################################################
 trt<-c(3,2) # factorial 3x2
 outdesign <-design.ab(trt, r=3, serie=2)
@@ -414,14 +414,14 @@ head(book12) # print of the field book
 
 
 ###################################################
-### code chunk number 47: tutorial.Rnw:507-509
+### code chunk number 47: tutorial.Rnw:509-511
 ###################################################
 book <- zigzag(outdesign)
 head(book)
 
 
 ###################################################
-### code chunk number 48: tutorial.Rnw:513-518
+### code chunk number 48: tutorial.Rnw:515-520
 ###################################################
 trt<-c(2,2,2)
 crd<-design.ab(trt, r=5, serie=2,design="crd")
@@ -431,7 +431,7 @@ head(crd$book)
 
 
 ###################################################
-### code chunk number 49: tutorial.Rnw:529-535
+### code chunk number 49: tutorial.Rnw:531-537
 ###################################################
 data(sweetpotato)
 model<-aov(yield~virus, data=sweetpotato)
@@ -442,60 +442,67 @@ detach(sweetpotato)
 
 
 ###################################################
-### code chunk number 50: tutorial.Rnw:538-540
+### code chunk number 50: tutorial.Rnw:540-542
 ###################################################
 df<-df.residual(model)
 MSerror<-deviance(model)/df
 
 
 ###################################################
-### code chunk number 51: tutorial.Rnw:547-549
+### code chunk number 51: tutorial.Rnw:549-551
 ###################################################
 # comparison <- LSD.test(yield,virus,df,MSerror)
 LSD.test(model, "virus",console=TRUE)
 
 
 ###################################################
-### code chunk number 52: tutorial.Rnw:554-556
+### code chunk number 52: tutorial.Rnw:556-558
 ###################################################
 # comparison <- LSD.test(yield, virus,df, MSerror, group=F)
 outLSD <-LSD.test(model, "virus", group=F,console=TRUE)
 
 
 ###################################################
-### code chunk number 53: tutorial.Rnw:563-564
+### code chunk number 53: tutorial.Rnw:565-566
 ###################################################
 print(outLSD)
 
 
 ###################################################
-### code chunk number 54: tutorial.Rnw:569-570
+### code chunk number 54: tutorial.Rnw:571-572
 ###################################################
 LSD.test(model, "virus", group=F, p.adj= "bon",console=TRUE)
 
 
 ###################################################
-### code chunk number 55: tutorial.Rnw:579-580
+### code chunk number 55: tutorial.Rnw:581-582
 ###################################################
 duncan.test(model, "virus",console=TRUE)
 
 
 ###################################################
-### code chunk number 56: tutorial.Rnw:586-588
+### code chunk number 56: tutorial.Rnw:588-590
 ###################################################
 # SNK.test(model, "virus", alpha=0.05,console=TRUE)
 SNK.test(model, "virus", group=FALSE,console=TRUE)
 
 
 ###################################################
-### code chunk number 57: tutorial.Rnw:595-597
+### code chunk number 57: tutorial.Rnw:596-598
+###################################################
+# REGW.test(model, "virus", alpha=0.05,console=TRUE)
+REGW.test(model, "virus", group=FALSE,console=TRUE)
+
+
+###################################################
+### code chunk number 58: tutorial.Rnw:605-607
 ###################################################
 outHSD<- HSD.test(model, "virus",console=TRUE)
 outHSD
 
 
 ###################################################
-### code chunk number 58: tutorial.Rnw:604-609
+### code chunk number 59: tutorial.Rnw:614-619
 ###################################################
 # variance analysis:
 anova(model)
@@ -505,26 +512,26 @@ detach(sweetpotato)
 
 
 ###################################################
-### code chunk number 59: tutorial.Rnw:613-614
+### code chunk number 60: tutorial.Rnw:623-624
 ###################################################
 outWaller <- waller.test(model, "virus", group=FALSE,console=FALSE)
 
 
 ###################################################
-### code chunk number 60: tutorial.Rnw:618-620
+### code chunk number 61: tutorial.Rnw:628-630
 ###################################################
 names(outWaller)
 print(outWaller$comparison)
 
 
 ###################################################
-### code chunk number 61: tutorial.Rnw:623-624
+### code chunk number 62: tutorial.Rnw:633-634
 ###################################################
 outWaller$statistics
 
 
 ###################################################
-### code chunk number 62: tutorial.Rnw:630-633
+### code chunk number 63: tutorial.Rnw:640-643
 ###################################################
 # analysis of variance: 
 scheffe.test(model,"virus", group=TRUE,console=TRUE,
@@ -532,20 +539,20 @@ main="Yield of sweetpotato\nDealt with different virus")
 
 
 ###################################################
-### code chunk number 63: tutorial.Rnw:637-638
+### code chunk number 64: tutorial.Rnw:647-648
 ###################################################
 outScheffe <- scheffe.test(model,"virus", group=FALSE, console=TRUE)
 
 
 ###################################################
-### code chunk number 64: tutorial.Rnw:643-645
+### code chunk number 65: tutorial.Rnw:653-655
 ###################################################
 # modelABC <-aov (y ~ A * B * C, data)
 # compare <-LSD.test (modelABC, c ("A", "B", "C"),console=TRUE)
 
 
 ###################################################
-### code chunk number 65: tutorial.Rnw:650-665
+### code chunk number 66: tutorial.Rnw:660-675
 ###################################################
 yield <-scan (text =
  "6 7 9 13 16 20 8 8 9
@@ -565,7 +572,7 @@ main = "Yield ~ block + nitrogen + clone + clone:nitrogen",console=TRUE)
 
 
 ###################################################
-### code chunk number 66: tutorial.Rnw:668-673 (eval = FALSE)
+### code chunk number 67: tutorial.Rnw:678-683 (eval = FALSE)
 ###################################################
 ## par(mar=c(3,3,2,0))
 ## pic1<-bar.err(outFactorial$means,variation="range",ylim=c(5,25), bar=FALSE,col=0,las=1)
@@ -575,7 +582,7 @@ main = "Yield ~ block + nitrogen + clone + clone:nitrogen",console=TRUE)
 
 
 ###################################################
-### code chunk number 67: tutorial.Rnw:680-688
+### code chunk number 68: tutorial.Rnw:690-698
 ###################################################
 #Example linear estimation and design of experiments. (Joshi)
 # Profesor de Estadistica, Institute of Social Sciences Agra, India
@@ -588,7 +595,7 @@ BIB.test(block, variety, y,console=TRUE)
 
 
 ###################################################
-### code chunk number 68: tutorial.Rnw:691-694
+### code chunk number 69: tutorial.Rnw:701-704
 ###################################################
 out <-BIB.test(block, trt=variety, y, test="tukey", group=FALSE, console=TRUE)
 names(out)
@@ -596,7 +603,7 @@ rm(block,variety)
 
 
 ###################################################
-### code chunk number 69: tutorial.Rnw:707-712
+### code chunk number 70: tutorial.Rnw:717-722
 ###################################################
 # alpha design 
 Genotype<-paste("geno",1:30,sep="")
@@ -606,14 +613,14 @@ plan<-design.alpha(Genotype,k,r,seed=5)
 
 
 ###################################################
-### code chunk number 70: tutorial.Rnw:718-720
+### code chunk number 71: tutorial.Rnw:728-730
 ###################################################
 yield <-c(5,2,7,6,4,9,7,6,7,9,6,2,1,1,3,2,4,6,7,9,8,7,6,4,3,2,2,1,1, 
           2,1,1,2,4,5,6,7,8,6,5,4,3,1,1,2,5,4,2,7,6,6,5,6,4,5,7,6,5,5,4)
 
 
 ###################################################
-### code chunk number 71: tutorial.Rnw:723-730
+### code chunk number 72: tutorial.Rnw:733-740
 ###################################################
 data<-data.frame(plan$book,yield)
 rm(yield,Genotype)
@@ -625,7 +632,7 @@ detach(data)
 
 
 ###################################################
-### code chunk number 72: tutorial.Rnw:763-769
+### code chunk number 73: tutorial.Rnw:773-779
 ###################################################
 trt<-c(1,8,5,5,2,9,2,7,3,6,4,9,4,6,9,8,7,6,1,5,8,3,2,7,3,7,2,1,3,4,6,4,9,5,8,1)
 yield<-c(48.76,10.83,12.54,11.07,22,47.43,27.67,30,13.78,37,42.37,39,14.46,30.69,42.01,
@@ -636,7 +643,7 @@ modelLattice<-PBIB.test(block,trt,sqr,yield,k=3,console=TRUE)
 
 
 ###################################################
-### code chunk number 73: tutorial.Rnw:784-789
+### code chunk number 74: tutorial.Rnw:794-799
 ###################################################
 block<-c(rep("I",7),rep("II",6),rep("III",7))
 trt<-c("A","B","C","D","g","k","l","A","B","C","D","e","i","A","B", "C",
@@ -646,46 +653,46 @@ head(data.frame(block, trt, yield))
 
 
 ###################################################
-### code chunk number 74: tutorial.Rnw:792-793
+### code chunk number 75: tutorial.Rnw:802-803
 ###################################################
 by(trt,block,as.character)
 
 
 ###################################################
-### code chunk number 75: tutorial.Rnw:796-797
+### code chunk number 76: tutorial.Rnw:806-807
 ###################################################
 by(yield,block,as.character)
 
 
 ###################################################
-### code chunk number 76: tutorial.Rnw:800-802
+### code chunk number 77: tutorial.Rnw:810-812
 ###################################################
 modelDAU<- DAU.test(block,trt,yield,method="lsd",console=TRUE)
 modelDAU$means
 
 
 ###################################################
-### code chunk number 77: tutorial.Rnw:804-806
+### code chunk number 78: tutorial.Rnw:814-816
 ###################################################
 modelDAU<- DAU.test(block,trt,yield,method="lsd",group=F,console=FALSE)
 head(modelDAU$comparison,8)
 
 
 ###################################################
-### code chunk number 78: tutorial.Rnw:823-825
+### code chunk number 79: tutorial.Rnw:833-835
 ###################################################
 data(corn)
 str(corn)
 
 
 ###################################################
-### code chunk number 79: tutorial.Rnw:830-831
+### code chunk number 80: tutorial.Rnw:840-841
 ###################################################
 str(kruskal)
 
 
 ###################################################
-### code chunk number 80: tutorial.Rnw:834-837
+### code chunk number 81: tutorial.Rnw:844-847
 ###################################################
 attach(corn)
 outKruskal<-kruskal(observation,method,group=TRUE, main="corn", console=TRUE)
@@ -693,13 +700,13 @@ detach(corn)
 
 
 ###################################################
-### code chunk number 81: tutorial.Rnw:842-843
+### code chunk number 82: tutorial.Rnw:852-853
 ###################################################
 str(friedman)
 
 
 ###################################################
-### code chunk number 82: tutorial.Rnw:846-852
+### code chunk number 83: tutorial.Rnw:856-862
 ###################################################
 rm(trt)
 data(grass)
@@ -710,13 +717,13 @@ detach(grass)
 
 
 ###################################################
-### code chunk number 83: tutorial.Rnw:856-857
+### code chunk number 84: tutorial.Rnw:866-867
 ###################################################
 str(waerden.test)
 
 
 ###################################################
-### code chunk number 84: tutorial.Rnw:860-864
+### code chunk number 85: tutorial.Rnw:870-874
 ###################################################
 rm(yield)
 data(sweetpotato)
@@ -725,26 +732,26 @@ outWaerden<-waerden.test(yield,virus,alpha=0.01,group=TRUE,console=TRUE)
 
 
 ###################################################
-### code chunk number 85: tutorial.Rnw:867-868
+### code chunk number 86: tutorial.Rnw:877-878
 ###################################################
 names(outWaerden)
 
 
 ###################################################
-### code chunk number 86: tutorial.Rnw:871-873
+### code chunk number 87: tutorial.Rnw:881-883
 ###################################################
 out<-waerden.test(yield,virus,group=F,console=TRUE)
 detach(sweetpotato)
 
 
 ###################################################
-### code chunk number 87: tutorial.Rnw:877-878
+### code chunk number 88: tutorial.Rnw:887-888
 ###################################################
 str(Median.test)
 
 
 ###################################################
-### code chunk number 88: tutorial.Rnw:881-888
+### code chunk number 89: tutorial.Rnw:891-898
 ###################################################
 data(sweetpotato)
 attach(sweetpotato)
@@ -756,13 +763,13 @@ outMedian$Medians
 
 
 ###################################################
-### code chunk number 89: tutorial.Rnw:893-894
+### code chunk number 90: tutorial.Rnw:903-904
 ###################################################
 str(durbin.test)
 
 
 ###################################################
-### code chunk number 90: tutorial.Rnw:897-906
+### code chunk number 91: tutorial.Rnw:907-916
 ###################################################
 days <-gl(7,3)
 chemical<-c("A","B","D","A","C","E","C","D","G","A","F","G", "B","C","F", 
@@ -776,7 +783,7 @@ out$statistics
 
 
 ###################################################
-### code chunk number 91: tutorial.Rnw:918-922
+### code chunk number 92: tutorial.Rnw:928-932
 ###################################################
 # model <-aov (yield ~ fertilizer, data = field) 
 # out <-LSD.test (model, "fertilizer", group = TRUE) 
@@ -785,7 +792,7 @@ str(bar.group)
 
 
 ###################################################
-### code chunk number 92: tutorial.Rnw:931-935
+### code chunk number 93: tutorial.Rnw:941-945
 ###################################################
 # model <-aov (yield ~ fertilizer, data = field) 
 # out <-LSD.test (model, "fertilizer", group = TRUE) 
@@ -794,7 +801,7 @@ str(bar.err)
 
 
 ###################################################
-### code chunk number 93: f4
+### code chunk number 94: f4
 ###################################################
 par(mfrow=c(1,2),mar=c(3,3,2,0),cex=0.7)
 c1<-colors()[480]; c2=colors()[65]; c3=colors()[15]; c4=colors()[140] 
@@ -806,7 +813,7 @@ main="Standard error \nG4",las=1)
 
 
 ###################################################
-### code chunk number 94: tutorial.Rnw:957-970 (eval = FALSE)
+### code chunk number 95: tutorial.Rnw:968-981 (eval = FALSE)
 ###################################################
 ## par(mfrow=c(2,2),cex=0.7,mar=c(3.5,1.5,3,0))
 ## C1<-bar.err(modelPBIB$means[1:7, ], ylim=c(0,9), col=0, main="C1", 
@@ -824,7 +831,20 @@ main="Standard error \nG4",las=1)
 
 
 ###################################################
-### code chunk number 95: tutorial.Rnw:981-987
+### code chunk number 96: f5
+###################################################
+# function (x, main = NULL, color1 = "red", color2 = "blue", 
+#    color3 = "black", cex.axis = 0.8, las = 1, pch = 20, 
+#    bty = "l", cex = 0.8, lwd = 1, xlab = "", ylab = "", 
+#   ...)
+# model : yield ~ virus
+# Important group=FALSE
+x<-HSD.test(model, "virus", group=FALSE)
+diffograph(x,cex.axis=0.9,xlab="Yield",ylab="Yield",cex=0.9)
+
+
+###################################################
+### code chunk number 97: tutorial.Rnw:1011-1017
 ###################################################
 options(digit=2)
 v1 <- c(10.2,8.8,8.8,9.3,9.6,7.2,8.4,9.6,7.9,10,9.3,8.0,10.1,9.4,10.8,6.3,7.4)
@@ -835,14 +855,14 @@ v5 <- c(9,9.2,8.8,10.6,8.3,9.3,9.6,8.8,7.9, 9.1,7.7,9.5,9.4,9.4,10.3,8.8,8.7)
 
 
 ###################################################
-### code chunk number 96: tutorial.Rnw:990-992
+### code chunk number 98: tutorial.Rnw:1020-1022
 ###################################################
 study <- data.frame(v1, v2, v3, v4, v5)
 rownames(study) <- LETTERS[1:17]
 
 
 ###################################################
-### code chunk number 97: tutorial.Rnw:997-1000
+### code chunk number 99: tutorial.Rnw:1027-1030
 ###################################################
 output <- stability.par(study, rep=4, MSerror=2)
 names(output)
@@ -850,7 +870,7 @@ print(output$stability)
 
 
 ###################################################
-### code chunk number 98: tutorial.Rnw:1005-1008
+### code chunk number 100: tutorial.Rnw:1035-1038
 ###################################################
 altitude<-c(1200, 1300, 800, 1600, 2400)
 stability <- stability.par(study,rep=4,MSerror=2, cova=TRUE, name.cov= "altitude",
@@ -858,7 +878,7 @@ file.cov=altitude)
 
 
 ###################################################
-### code chunk number 99: tutorial.Rnw:1015-1019
+### code chunk number 101: tutorial.Rnw:1045-1049
 ###################################################
 data <- data.frame(name=row.names(study), study)
 output<-stability.nonpar(data, "YIELD", ranking=TRUE)
@@ -867,19 +887,19 @@ output$statistics
 
 
 ###################################################
-### code chunk number 100: tutorial.Rnw:1036-1037
+### code chunk number 102: tutorial.Rnw:1066-1067
 ###################################################
 str(AMMI)
 
 
 ###################################################
-### code chunk number 101: tutorial.Rnw:1040-1041
+### code chunk number 103: tutorial.Rnw:1070-1071
 ###################################################
 str(plot.AMMI)
 
 
 ###################################################
-### code chunk number 102: tutorial.Rnw:1044-1052
+### code chunk number 104: tutorial.Rnw:1074-1082
 ###################################################
 rdto <- c(study[,1], study[,2], study[,3], study[,4], study[,5])
 environment <- gl(5,17)
@@ -892,14 +912,14 @@ rm(rdto,environment,genotype)
 
 
 ###################################################
-### code chunk number 103: f5
+### code chunk number 105: f6
 ###################################################
 par(cex=0.8,mar=c(4,4,1,0))
 plot(model,type=1,las=1)
 
 
 ###################################################
-### code chunk number 104: tutorial.Rnw:1078-1087
+### code chunk number 106: tutorial.Rnw:1108-1117
 ###################################################
 data(plrv)
 attach(plrv)
@@ -913,7 +933,7 @@ print(index[order(index[,4]),])
 
 
 ###################################################
-### code chunk number 105: f6
+### code chunk number 107: f7
 ###################################################
 par(cex=0.6,mar=c(3,3,2,0))
 data(pamCIP)
@@ -922,7 +942,7 @@ output<-consensus(pamCIP,distance="binary", method="complete", nboot=5)
 
 
 ###################################################
-### code chunk number 106: f7
+### code chunk number 108: f8
 ###################################################
 par(cex=0.6,mar=c(3,3,1.5,0))
 out1<- hcut(output,h=0.4,group=8,type="t",edgePar = list(lty=1:2, col=colors()[c(42,84)]),
@@ -930,13 +950,13 @@ main="group 8" ,col.text="blue",cex.text=1,las=1)
 
 
 ###################################################
-### code chunk number 107: tutorial.Rnw:1123-1124
+### code chunk number 109: tutorial.Rnw:1153-1154
 ###################################################
 names(output)
 
 
 ###################################################
-### code chunk number 108: tutorial.Rnw:1130-1133
+### code chunk number 110: tutorial.Rnw:1160-1163
 ###################################################
 dend <- as.dendrogram(output$dendrogram)
 data <- output$table.dend
@@ -944,7 +964,7 @@ head(output$table.dend)
 
 
 ###################################################
-### code chunk number 109: tutorial.Rnw:1135-1138 (eval = FALSE)
+### code chunk number 111: tutorial.Rnw:1165-1168 (eval = FALSE)
 ###################################################
 ## par(mar=c(3,3,1,1),cex=0.6)
 ## plot(dend,type="r",edgePar = list(lty=1:2, col=colors()[c(42,84)]) ,las=1)
@@ -952,7 +972,7 @@ head(output$table.dend)
 
 
 ###################################################
-### code chunk number 110: tutorial.Rnw:1145-1149
+### code chunk number 112: tutorial.Rnw:1175-1179
 ###################################################
 data(soil)
 # set.seed(9473)
@@ -961,7 +981,7 @@ h<-graph.freq(simulated,nclass=7,plot=FALSE)
 
 
 ###################################################
-### code chunk number 111: f8
+### code chunk number 113: f9
 ###################################################
 par(mar=c(2,0,2,1),cex=0.6)
 plot(density(soil$pH),axes=F,main="pH density of the soil\ncon Ralstonia",xlab="",lwd=4)
@@ -971,25 +991,25 @@ legend("topright",c("Original","Simulated"),lty=c(1,4),col=c("black", "blue"), l
 
 
 ###################################################
-### code chunk number 112: tutorial.Rnw:1164-1165
+### code chunk number 114: tutorial.Rnw:1194-1195
 ###################################################
 round(table.freq(h),2)
 
 
 ###################################################
-### code chunk number 113: tutorial.Rnw:1168-1169
+### code chunk number 115: tutorial.Rnw:1198-1199
 ###################################################
 summary(soil$pH)
 
 
 ###################################################
-### code chunk number 114: tutorial.Rnw:1172-1173
+### code chunk number 116: tutorial.Rnw:1202-1203
 ###################################################
 summary(simulated)
 
 
 ###################################################
-### code chunk number 115: tutorial.Rnw:1179-1186
+### code chunk number 117: tutorial.Rnw:1209-1216
 ###################################################
 data(potato)
 potato[,1]<-as.factor(potato[,1])
@@ -1001,19 +1021,19 @@ print(Xsol,na.print = "")
 
 
 ###################################################
-### code chunk number 116: tutorial.Rnw:1195-1196
+### code chunk number 118: tutorial.Rnw:1225-1226
 ###################################################
 simModel <- simulation.model(model, potato, k=100,console=TRUE)
 
 
 ###################################################
-### code chunk number 117: tutorial.Rnw:1198-1199
+### code chunk number 119: tutorial.Rnw:1228-1229
 ###################################################
 ab<-simModel$simulation[3,3]
 
 
 ###################################################
-### code chunk number 118: tutorial.Rnw:1206-1212
+### code chunk number 120: tutorial.Rnw:1236-1242
 ###################################################
 corr.x<- matrix(c(1,0.5,0.5,1),c(2,2))
 corr.y<- rbind(0.6,0.7)
@@ -1024,13 +1044,13 @@ output<-path.analysis(corr.x,corr.y)
 
 
 ###################################################
-### code chunk number 119: tutorial.Rnw:1214-1215
+### code chunk number 121: tutorial.Rnw:1244-1245
 ###################################################
 output
 
 
 ###################################################
-### code chunk number 120: tutorial.Rnw:1249-1256
+### code chunk number 122: tutorial.Rnw:1279-1286
 ###################################################
 rm(list=ls())
 data(heterosis)
@@ -1042,7 +1062,7 @@ detach(site2)
 
 
 ###################################################
-### code chunk number 121: f9
+### code chunk number 123: f10
 ###################################################
 par(mar=c(3,3,4,0),cex=0.7)
 data(rice)
@@ -1051,14 +1071,14 @@ table<-index.smith(rice,pch=19, col="blue",
 
 
 ###################################################
-### code chunk number 122: tutorial.Rnw:1274-1276
+### code chunk number 124: tutorial.Rnw:1304-1306
 ###################################################
 uniformity <- data.frame(table$uniformity)
 head(uniformity)
 
 
 ###################################################
-### code chunk number 123: tutorial.Rnw:1284-1287
+### code chunk number 125: tutorial.Rnw:1314-1317
 ###################################################
 data(paracsho)
 species <- paracsho[79:87,4:6]
@@ -1066,13 +1086,13 @@ species
 
 
 ###################################################
-### code chunk number 124: tutorial.Rnw:1290-1291
+### code chunk number 126: tutorial.Rnw:1320-1321
 ###################################################
 output <- index.bio(species[,3],method="Shannon",level=95,nboot=200)
 
 
 ###################################################
-### code chunk number 125: tutorial.Rnw:1297-1303
+### code chunk number 127: tutorial.Rnw:1327-1333
 ###################################################
 data(soil)
 correlation(soil[,2:4],method="pearson")
@@ -1083,7 +1103,7 @@ detach(soil)
 
 
 ###################################################
-### code chunk number 126: tutorial.Rnw:1314-1318
+### code chunk number 128: tutorial.Rnw:1344-1348
 ###################################################
 data(RioChillon)
 attach(RioChillon$babies)
@@ -1092,7 +1112,7 @@ detach(RioChillon$babies)
 
 
 ###################################################
-### code chunk number 127: tutorial.Rnw:1333-1336
+### code chunk number 129: tutorial.Rnw:1363-1366
 ###################################################
 data(sweetpotato)
 model <- model<-aov(yield ~ virus, data=sweetpotato)
@@ -1100,25 +1120,25 @@ cv.model(model)
 
 
 ###################################################
-### code chunk number 128: tutorial.Rnw:1343-1344
+### code chunk number 130: tutorial.Rnw:1373-1374
 ###################################################
 x<-c(3,4,5,2,3,4,5,6,4,NA,7)
 
 
 ###################################################
-### code chunk number 129: tutorial.Rnw:1347-1348
+### code chunk number 131: tutorial.Rnw:1377-1378
 ###################################################
 skewness(x)
 
 
 ###################################################
-### code chunk number 130: tutorial.Rnw:1351-1352
+### code chunk number 132: tutorial.Rnw:1381-1382
 ###################################################
 kurtosis(x)
 
 
 ###################################################
-### code chunk number 131: tutorial.Rnw:1358-1367
+### code chunk number 133: tutorial.Rnw:1388-1397
 ###################################################
 q<-5
 f<-15
@@ -1132,7 +1152,7 @@ for(i in 1:n) y[i,3]<-waller(K[i],q,f,Fc=8)
 
 
 ###################################################
-### code chunk number 132: tutorial.Rnw:1371-1378 (eval = FALSE)
+### code chunk number 134: tutorial.Rnw:1401-1408 (eval = FALSE)
 ###################################################
 ## par(mar=c(3,3,4,0),cex=0.7)
 ## plot(K,y[,1],type="l",col="blue",ylab="waller",bty="l")
@@ -1144,7 +1164,7 @@ for(i in 1:n) y[i,3]<-waller(K[i],q,f,Fc=8)
 
 
 ###################################################
-### code chunk number 133: tutorial.Rnw:1382-1398
+### code chunk number 135: tutorial.Rnw:1412-1428
 ###################################################
 K<-100
 Fc<-1.2
@@ -1165,7 +1185,7 @@ print(W.D)
 
 
 ###################################################
-### code chunk number 134: tutorial.Rnw:1404-1409
+### code chunk number 136: tutorial.Rnw:1434-1439
 ###################################################
 days<-c(7,14,21,28,35,42)
 evaluation<-data.frame(E1=10,E2=40,E3=50,E4=70,E5=80,E6=90)
@@ -1175,14 +1195,14 @@ relative1 <-round(audpc(evaluation,days,"relative"),2)
 
 
 ###################################################
-### code chunk number 135: tutorial.Rnw:1415-1417
+### code chunk number 137: tutorial.Rnw:1445-1447
 ###################################################
 absolute2 <-audps(evaluation,days)
 relative2 <-round(audps(evaluation,days,"relative"),2)
 
 
 ###################################################
-### code chunk number 136: f10
+### code chunk number 138: f11
 ###################################################
 par(mfrow=c(1,2),mar=c(3,3,1,0),cex=0.7)
 plot(days, evaluation,type="h",ylim=c(0,100),axes=F,col= colors()[42],xlab="Days", ylab="Evaluation")
@@ -1206,7 +1226,7 @@ text(13,70,substitute(paste("Audps Rel.=",A2),list(A2=relative2)))
 
 
 ###################################################
-### code chunk number 137: tutorial.Rnw:1454-1462
+### code chunk number 139: tutorial.Rnw:1484-1492
 ###################################################
 data(potato)
 potato[,1]<-as.factor(potato[,1])
@@ -1219,7 +1239,7 @@ detach(potato)
 
 
 ###################################################
-### code chunk number 138: tutorial.Rnw:1471-1497
+### code chunk number 140: tutorial.Rnw:1501-1527
 ###################################################
 f <- system.file("external/weather.csv", package="agricolae")
 weather <- read.csv(f,header=FALSE)
@@ -1250,7 +1270,7 @@ main<-"Cultivar: NICOLA"
 
 
 ###################################################
-### code chunk number 139: f11
+### code chunk number 141: f12
 ###################################################
 par(mar=c(3,3,4,0),cex=0.7)
 #--------------------------
@@ -1260,7 +1280,7 @@ xlab="Time (days after emergence)", ylab="Severity (Percentage)")
 
 
 ###################################################
-### code chunk number 140: tutorial.Rnw:1512-1515
+### code chunk number 142: tutorial.Rnw:1542-1545
 ###################################################
 head(model$Gfile)
 str(model$Ofile)
@@ -1268,7 +1288,7 @@ head(model$Ofile[,1:7])
 
 
 ###################################################
-### code chunk number 141: tutorial.Rnw:1519-1525
+### code chunk number 143: tutorial.Rnw:1549-1555
 ###################################################
 x<- model$Ofile$nday
 y<- model$Ofile$SimSeverity
@@ -1279,7 +1299,7 @@ Max<-model$Gfile$MaxObs
 
 
 ###################################################
-### code chunk number 142: tutorial.Rnw:1527-1534 (eval = FALSE)
+### code chunk number 144: tutorial.Rnw:1557-1564 (eval = FALSE)
 ###################################################
 ## par(mar=c(3,2.5,1,0),cex=0.7)
 ## plot(x,y,type="l",xlim=c(65,95),lwd=1.5,xlab="Time (days after emergence)",
